@@ -4,7 +4,8 @@ get_contents_ftp <- function(ftp_url) {
   my_html <- xml2::read_html(ftp_url)
 
   all_links <- my_html %>%
-    rvest::html_nodes('td') %>%
+    rvest::html_node('pre') %>%
+    rvest::html_nodes('a') %>%
     rvest::html_text()
 
   idx <- stringr::str_detect(
@@ -20,7 +21,8 @@ get_contents_ftp <- function(ftp_url) {
   df_out <- dplyr::tibble(file_name = all_links,
                           full_links,
                           year_files) %>%
-    dplyr::arrange(year_files)
+    dplyr::arrange(year_files) %>%
+    stats::na.omit()
 
   return(df_out)
 
